@@ -1,5 +1,5 @@
 package AnyEvent::Handle::UDP;
-$AnyEvent::Handle::UDP::VERSION = '0.047';
+$AnyEvent::Handle::UDP::VERSION = '0.048';
 use strict;
 use warnings;
 
@@ -294,8 +294,11 @@ sub _push_writer {
 
 sub destroy {
 	my $self = shift;
-	@{$self}{qw/timer rtimer wtimer reader writer/} = ();
+	delete @{$self}{qw/reader writer/};
 	close $self->{fh};
+	$self->timeout(0);
+	$self->rtimeout(0);
+	$self->wtimeout(0);
 	return;
 }
 
@@ -315,7 +318,7 @@ AnyEvent::Handle::UDP - client/server UDP handles for AnyEvent
 
 =head1 VERSION
 
-version 0.047
+version 0.048
 
 =head1 SYNOPSIS
 
